# coding: utf-8
#!/usr/bin/env python

# Stórveldið - BravóTV og Mikligarður
# Author:  Haukur H. Þórsson (haukurhaf.net)

import urllib, urllib2, re, xbmcaddon, xbmcplugin, xbmcgui, xbmc, json
from datetime import datetime, timedelta
from BeautifulSoup import BeautifulSoup
import os

# Plugin constants 
__addonid__   = "plugin.video.storveldid"
__addon__     = xbmcaddon.Addon(id=__addonid__)

user_agent = 'Mozilla/5.0 (Windows; U; Windows NT 5.1; en-GB; rv:1.9.0.3) Gecko/2008092417 Firefox/3.0.3'
action_key = None
action_value = None
name = None

def listChannels():
	channels = []
	channels.append({"name": "Bravó TV", "id": "bravotv"})
	channels.append({"name": "Mikligarður", "id": "mikligardur"})
	for channel in channels:
		addMenuItem(channel["name"], 'listshows', channel["id"], True)

def listShows(channelid):
	if (channelid == "mikligardur"):
		listCategories("http://www.mikli.is")
	elif (channelid == "bravotv"):
		listStreams("http://bravotv.is/api/new")

def listCategories(url):
	categories = []
	categories.append({"name": "Lifandi útsending", "url": "mikli-live"})
	categories.append({"name": "Fjölskylda", "url": "http://www.mikli.is/api/family"})
	categories.append({"name": "Heimili", "url": "http://www.mikli.is/api/home"})
	categories.append({"name": "Matur", "url": "http://www.mikli.is/api/food"})
	categories.append({"name": "Lífsstíll", "url": "http://www.mikli.is/api/lifestyle"})
	categories.append({"name": "Annað", "url": "http://www.mikli.is/api/other"})
	for category in categories:
		addMenuItem(category["name"], 'liststreams', category["url"], True)

def listStreams(url):
	if (url == "mikli-live" or url == "bravotv-live"):
		listLiveStreams(url)
	else:
		jsonData = fetchPage(url)
		jsonObject = json.loads(jsonData)
		if ("items" in jsonObject):
			addMenuItem("Lifandi útsending", 'liststreams', "bravotv-live", True)				
			for stream in jsonObject["items"]:
				baseUrl = url[:url.index("/api")]
				streamUrl = baseUrl + "/api/stream/" + str(stream["stream"]["id"])
				thumbUrl = baseUrl+stream["stream"]["img"]
				addMenuItem(stream["title"].encode('utf-8'), 'selectsource', streamUrl, True, thumbUrl)
								
			totalPages = jsonObject["pagination"]["pages"]
			currentPage = jsonObject["pagination"]["currentPage"]
			if (currentPage <= totalPages):				
				if ("?page" in url):
					nextUrl = url[:url.index("?page")]
				else:
					nextUrl = url
				nextUrl = nextUrl + "?page=" + str(currentPage+1)
				addMenuItem("Næsta síða", 'liststreams', nextUrl, True)
		else:
			for stream in jsonObject:
				baseUrl = url[:url.index("/api")]
				streamUrl = baseUrl + "/api/stream/" + str(stream["id"])
				thumbUrl = baseUrl+stream["stream"]["img"]
				addMenuItem(stream["title"].encode('utf-8'), 'selectsource', streamUrl, True, thumbUrl)

def listSources(url):
	jsonData = fetchPage(url)
	jsonObject = json.loads(jsonData)
	for source in jsonObject["stream"]["sources"]:
		addMenuItem(source["label"].encode('utf-8'), 'play', source["file"], False)	
		
def listLiveStreams(channel):
	showDialog("Coming soon, hopefully!")
#LIB

def get_params():
	param=[]
	paramstring=sys.argv[2]
	if len(paramstring)>=2:
		params=sys.argv[2]
		cleanedparams=params.replace('?','')
		if (params[len(params)-1]=='/'):
			params=params[0:len(params)-2]
		pairsofparams=cleanedparams.split('&')
		param={}
		for i in range(len(pairsofparams)):
			splitparams={}
			splitparams=pairsofparams[i].split('=')
			if (len(splitparams))==2:
				param[splitparams[0]]=splitparams[1]

	return param

def play(url):
	xbmc.Player(xbmc.PLAYER_CORE_DVDPLAYER).play(url)

def addMenuItem(name, action_key, action_value, is_folder = True, iconimage='DefaultFolder.png'):
	u=sys.argv[0]+"?action_key="+urllib.quote_plus(action_key)+"&action_value="+str(action_value)+"&name="+urllib.quote_plus(name)
	liz=xbmcgui.ListItem(name, iconImage=iconimage, thumbnailImage=iconimage)
	liz.setInfo(type="Video", infoLabels={ "Title": name } )
	return xbmcplugin.addDirectoryItem(handle=int(sys.argv[1]),url=u,listitem=liz,isFolder=is_folder)

def showDialog(message):
	dialog = xbmcgui.Dialog()
	dialog.ok('Stórveldið - BravóTV - Mikligarður', message)        

def fetchPage(url):
	req = urllib2.Request(url)
	req.add_header('User-Agent', user_agent)
	response = urllib2.urlopen(req)
	html = response.read()
	response.close()
	return html


params=get_params()
try:
	action_key = urllib.unquote_plus(params["action_key"])
	action_value = urllib.unquote_plus(params["action_value"])
	name = urllib.unquote_plus(params["name"])
except:
	pass

if action_key is None:
	listChannels()
elif action_key == 'listshows':
	listShows(action_value)
elif action_key == 'liststreams':
	listStreams(action_value)
elif action_key == 'selectsource':
	listSources(action_value)
elif action_key == 'play':
	play(action_value)
        
xbmcplugin.endOfDirectory(int(sys.argv[1]))